@@ -7,6 +7,9 @@ class Settings(BaseSettings):
     git_dir = pathlib.Path().cwd()
     commits = 5
     branches = 1
+    diverge_at = 0
+    merge = ""
+    no_subdir = False
 
     class Config:
         env_prefix = "git_dummy_"
